import { h } from 'preact'
import Logo from '../Logo'
import 'regenerator-runtime/runtime'

import { PeerTubePlayer } from '@peertube/embed-api'
import { VideoWrapper, Iframe, Overlay } from './styles'
import { useEffect, useRef, useState } from 'preact/hooks'

const Video = ({ playing, setPlaying, src }) => {
  const videoiFrame = useRef(null)
  const overlayTimeout = useRef(null)
  const [videoReady, setVideoReady] = useState(false)
  const [overlayActive, setOverlayActiveState] = useState(true)
  const ptVideo = useRef(null)

  useEffect(() => {
    const setVideo = async () => {
      const player = new PeerTubePlayer(videoiFrame.current)
      await player.ready

      ptVideo.current = player
      player.setVolume(100)
      setVideoReady(true)
    }
    setVideo()
  }, [])

  useEffect(() => {
    const { current: player } = ptVideo

    if (!videoReady) return

    if (playing) {
      setOverlayActiveState(false)
      player.play()
    } else {
      setOverlayActiveState(true)
      player.pause()
    }
  }, [playing])

  const activateOverlay = () => {
    clearTimeout(overlayTimeout.current)
    setOverlayActiveState(true)

    overlayTimeout.current = setTimeout(
      () => setOverlayActiveState(false),
      2000
    )
  }

  return (
    <VideoWrapper
      $active={overlayActive || !playing}
      onClick={() => setPlaying(!playing)}
      onMouseMove={activateOverlay}
    >
      <Overlay>
        <Logo active={overlayActive || !playing}></Logo>
      </Overlay>
      <Iframe
        sandbox="allow-same-origin allow-scripts allow-popups"
        src={`${src}?api=1&controls=false`}
        frameborder="0"
        allowfullscreen
        ref={videoiFrame}
      />
    </VideoWrapper>
  )
}

export default Video
